'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

var NotificationContext = React__default.createContext({});

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(source, true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(source).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  }
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArray(iter) {
  if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}

function _iterableToArrayLimit(arr, i) {
  if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
    return;
  }

  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance");
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

var NotificationContainer = (function (_ref) {
  var Component = _ref.component;
  var context = React.useContext(NotificationContext);
  return React__default.createElement(React__default.Fragment, null, context.notifications.map(function (props) {
    return React__default.createElement(Component, _extends({
      key: props.id,
      onClose: function onClose() {
        return context.update(props.id, 'open', false);
      }
    }, props));
  }));
});

var provider = (function (_ref) {
  var children = _ref.children,
      component = _ref.component;

  var _useState = React.useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      notifications = _useState2[0],
      setNotifications = _useState2[1];

  var push = function push(obj) {
    var data = _toConsumableArray(notifications).filter(function (item, index) {
      return index < 2 || item.open;
    });

    data.push(obj);
    setNotifications(data);
  };

  var pop = function pop() {
    var data = _toConsumableArray(notifications);

    data.pop();
    setNotifications(data);
  };

  var update = function update(id, prop, value) {
    var index = notifications.findIndex(function (elem) {
      return elem.id === id;
    });
    var item = Object.assign({}, notifications[index]);
    item[prop] = value;

    var data = _toConsumableArray(notifications);

    data.splice(index, 1, item);
    setNotifications(data);
  };

  return React__default.createElement(React__default.Fragment, null, React__default.createElement(NotificationContext.Provider, {
    value: {
      notifications: notifications,
      push: push,
      pop: pop,
      update: update
    }
  }, children, React__default.createElement(NotificationContainer, {
    component: component
  })));
});

var hook = (function () {
  var context = React.useContext(NotificationContext);

  var push = function push(type, message, props) {
    var id = (+new Date() * Math.random()).toString(32);
    context.push(_objectSpread2({
      type: type,
      message: message,
      id: id,
      open: true
    }, props));
  };

  return {
    showSuccess: function showSuccess(message, props) {
      return push('success', message, props);
    },
    showInfo: function showInfo(message, props) {
      return push('info', message, props);
    },
    showWarning: function showWarning(message, props) {
      return push('warning', message, props);
    },
    showError: function showError(message, props) {
      return push('error', message, props);
    }
  };
});

exports.NotificationContext = NotificationContext;
exports.NotificationProvider = provider;
exports.useNotification = hook;
//# sourceMappingURL=index.js.map
